@@ -51,7 +51,7 @@ def artifact_matcher(version):
     def matches(fn):
         return (
             fn.startswith(prefix) and
-            os.path.splitext(fn)[1] in ('.exe', '.whl') and
+            fn.endswith('.whl') and
             not fn.endswith('-none-any.whl')
         ) or fn == '{}.tar.gz'.format(prefix)
     return matches
